# Warden Scan Report

**Report ID:** `scan-20251223-221151`
**Timestamp:** 2025-12-23T19:11:51.525Z
**Status:** COMPLETED

---

## Summary

- **Directory:** `/Users/alper/Documents/Development/Personal/warden-core/examples`
- **Files Scanned:** 9/9
- **Duration:** 1.9s
- **Total Issues:** 119

### Issues by Severity

- 🔴 **Critical:** 4
- 🟠 **High:** 14
- 🟡 **Medium:** 98
- 🟢 **Low:** 3

### Top Files with Issues

| File | Issues | 🔴 | 🟠 | 🟡 | 🟢 |
|------|--------|----|----|----|
| `./ipc_example.py` | 59 | 0 | 7 | 50 | 2 |
| `./custom-frames/redis-security/test_manual.py` | 47 | 0 | 2 | 45 | 0 |
| `./custom-frames/redis-security/test_examples/secure_redis.py` | 7 | 0 | 3 | 3 | 1 |
| `./custom-frames/redis-security/test_examples/insecure_redis.py` | 3 | 2 | 1 | 0 | 0 |
| `./custom-frames/redis-security/frame.py` | 1 | 1 | 0 | 0 | 0 |
| `./custom-frames/redis-security/tests/test_frame.py` | 1 | 0 | 1 | 0 | 0 |
| `./test_security.py` | 1 | 1 | 0 | 0 | 0 |

### Validation Frames

| Frame | Executions | Issues | Avg Duration |
|-------|------------|--------|-------------|
| Fuzz Testing | 6 | 95 | 0.00s |
| Property Testing | 6 | 11 | 0.00s |
| Security Analysis | 9 | 5 | 0.00s |
| Architectural Consistency | 6 | 3 | 0.00s |
| Stress Testing | 6 | 3 | 0.00s |
| Chaos Engineering | 6 | 1 | 0.00s |
| Orphan Code Analysis | 6 | 1 | 0.28s |
| Project Architecture Analysis | 6 | 0 | 0.00s |
| Git Changes Analysis | 6 | 0 | 0.01s |

---

*Generated by Warden CLI v0.1.0*
